@@ -19,7 +19,7 @@ use crate::{
     request::{HACK_SWOOLE_ON_REQUEST_FUNCTION_NAME, IS_SWOOLE},
     util::catch_unwind_result,
 };
-use anyhow::{bail, Context};
+use anyhow::{Context, bail};
 use phper::{
     objects::ZObj,
     strings::ZStr,
@@ -70,163 +70,170 @@ static mut ORI_EXECUTE_EX: Option<unsafe extern "C" fn(execute_data: *mut sys::z
 unsafe extern "C" fn execute_internal(
     execute_data: *mut sys::zend_execute_data, return_value: *mut sys::zval,
 ) {
-    let (execute_data, return_value) = match (
-        ExecuteData::try_from_mut_ptr(execute_data),
-        ZVal::try_from_mut_ptr(return_value),
-    ) {
-        (Some(execute_data), Some(return_value)) => (execute_data, return_value),
-        (execute_data, return_value) => {
-            ori_execute_internal(execute_data, return_value);
-            return;
-        }
-    };
+    unsafe {
+        let (execute_data, return_value) = match (
+            ExecuteData::try_from_mut_ptr(execute_data),
+            ZVal::try_from_mut_ptr(return_value),
+        ) {
+            (Some(execute_data), Some(return_value)) => (execute_data, return_value),
+            (execute_data, return_value) => {
+                ori_execute_internal(execute_data, return_value);
+                return;
+            }
+        };
 
-    let (function_name, class_name) = match get_function_and_class_name(execute_data) {
-        Ok(x) => x,
-        Err(err) => {
-            error!(?err, "get function and class name failed");
+        let (function_name, class_name) = match get_function_and_class_name(execute_data) {
+            Ok(x) => x,
+            Err(err) => {
+                error!(?err, "get function and class name failed");
+                ori_execute_internal(Some(execute_data), Some(return_value));
+                return;
+            }
+        };
+
+        trace!(
+            ?function_name,
+            ?class_name,
+            "execute_internal function and class name"
+        );
+
+        let function_name = match function_name {
+            Some(function_name) => function_name,
+            None => {
+                ori_execute_internal(Some(execute_data), Some(return_value));
+                return;
+            }
+        };
+
+        if function_name == HACK_SWOOLE_ON_REQUEST_FUNCTION_NAME {
             ori_execute_internal(Some(execute_data), Some(return_value));
             return;
         }
-    };
 
-    trace!(
-        ?function_name,
-        ?class_name,
-        "execute_internal function and class name"
-    );
-
-    let function_name = match function_name {
-        Some(function_name) => function_name,
-        None => {
+        let Some((before, after)) = select_plugin_hook(class_name.as_deref(), &function_name)
+        else {
             ori_execute_internal(Some(execute_data), Some(return_value));
             return;
-        }
-    };
+        };
 
-    if function_name == HACK_SWOOLE_ON_REQUEST_FUNCTION_NAME {
-        ori_execute_internal(Some(execute_data), Some(return_value));
-        return;
-    }
-
-    let Some((before, after)) = select_plugin_hook(class_name.as_deref(), &function_name) else {
-        ori_execute_internal(Some(execute_data), Some(return_value));
-        return;
-    };
-
-    let request_id = infer_request_id(execute_data);
-    trace!(
-        ?request_id,
-        ?function_name,
-        ?class_name,
-        "execute_internal infer request id"
-    );
-
-    let result = catch_unwind_result(AssertUnwindSafe(|| before(request_id, execute_data)));
-    if let Err(err) = &result {
-        error!(
+        let request_id = infer_request_id(execute_data);
+        trace!(
             ?request_id,
             ?function_name,
             ?class_name,
-            ?err,
-            "before execute internal"
+            "execute_internal infer request id"
         );
-    }
 
-    ori_execute_internal(Some(execute_data), Some(return_value));
-
-    // If before hook return error, don't execute the after hook.
-    if let Ok(data) = result {
-        if let Err(err) = catch_unwind_result(AssertUnwindSafe(|| {
-            after(request_id, data, execute_data, return_value)
-        })) {
+        let result = catch_unwind_result(AssertUnwindSafe(|| before(request_id, execute_data)));
+        if let Err(err) = &result {
             error!(
                 ?request_id,
                 ?function_name,
                 ?class_name,
                 ?err,
-                "after execute internal"
+                "before execute internal"
             );
         }
+
+        ori_execute_internal(Some(execute_data), Some(return_value));
+
+        // If before hook return error, don't execute the after hook.
+        if let Ok(data) = result {
+            if let Err(err) = catch_unwind_result(AssertUnwindSafe(|| {
+                after(request_id, data, execute_data, return_value)
+            })) {
+                error!(
+                    ?request_id,
+                    ?function_name,
+                    ?class_name,
+                    ?err,
+                    "after execute internal"
+                );
+            }
+        }
     }
 }
 
 unsafe extern "C" fn execute_ex(execute_data: *mut sys::zend_execute_data) {
-    let execute_data = match ExecuteData::try_from_mut_ptr(execute_data) {
-        Some(execute_data) => execute_data,
-        None => {
-            ori_execute_ex(None);
-            return;
-        }
-    };
+    unsafe {
+        let execute_data = match ExecuteData::try_from_mut_ptr(execute_data) {
+            Some(execute_data) => execute_data,
+            None => {
+                ori_execute_ex(None);
+                return;
+            }
+        };
 
-    let (function_name, class_name) = match get_function_and_class_name(execute_data) {
-        Ok(x) => x,
-        Err(err) => {
-            error!(?err, "get function and class name failed");
+        let (function_name, class_name) = match get_function_and_class_name(execute_data) {
+            Ok(x) => x,
+            Err(err) => {
+                error!(?err, "get function and class name failed");
+                ori_execute_ex(Some(execute_data));
+                return;
+            }
+        };
+
+        trace!(
+            ?function_name,
+            ?class_name,
+            "execute_ex function and class name"
+        );
+
+        let function_name = match function_name {
+            Some(function_name) => function_name,
+            None => {
+                ori_execute_ex(Some(execute_data));
+                return;
+            }
+        };
+
+        let Some((before, after)) = select_plugin_hook(class_name.as_deref(), &function_name)
+        else {
             ori_execute_ex(Some(execute_data));
             return;
-        }
-    };
+        };
 
-    trace!(
-        ?function_name,
-        ?class_name,
-        "execute_ex function and class name"
-    );
-
-    let function_name = match function_name {
-        Some(function_name) => function_name,
-        None => {
-            ori_execute_ex(Some(execute_data));
-            return;
-        }
-    };
-
-    let Some((before, after)) = select_plugin_hook(class_name.as_deref(), &function_name) else {
-        ori_execute_ex(Some(execute_data));
-        return;
-    };
-
-    let request_id = infer_request_id(execute_data);
-    trace!(
-        ?request_id,
-        ?function_name,
-        ?class_name,
-        "execute_ex infer request id"
-    );
-
-    let result = catch_unwind_result(AssertUnwindSafe(|| before(request_id, execute_data)));
-    if let Err(err) = &result {
-        error!(
+        let request_id = infer_request_id(execute_data);
+        trace!(
             ?request_id,
             ?function_name,
             ?class_name,
-            ?err,
-            "before execute ex"
+            "execute_ex infer request id"
         );
-    }
 
-    ori_execute_ex(Some(execute_data));
-
-    // If before hook return error, don't execute the after hook.
-    if let Ok(data) = result {
-        let mut null = ZVal::from(());
-        let return_value = match ZVal::try_from_mut_ptr((*execute_data.as_mut_ptr()).return_value) {
-            Some(return_value) => return_value,
-            None => &mut null,
-        };
-        if let Err(err) = catch_unwind_result(AssertUnwindSafe(|| {
-            after(request_id, data, execute_data, return_value)
-        })) {
+        let result = catch_unwind_result(AssertUnwindSafe(|| before(request_id, execute_data)));
+        if let Err(err) = &result {
             error!(
                 ?request_id,
                 ?function_name,
                 ?class_name,
                 ?err,
-                "after execute ex"
+                "before execute ex"
             );
         }
+
+        ori_execute_ex(Some(execute_data));
+
+        // If before hook return error, don't execute the after hook.
+        if let Ok(data) = result {
+            let mut null = ZVal::from(());
+            let return_value =
+                match ZVal::try_from_mut_ptr((*execute_data.as_mut_ptr()).return_value) {
+                    Some(return_value) => return_value,
+                    None => &mut null,
+                };
+            if let Err(err) = catch_unwind_result(AssertUnwindSafe(|| {
+                after(request_id, data, execute_data, return_value)
+            })) {
+                error!(
+                    ?request_id,
+                    ?function_name,
+                    ?class_name,
+                    ?err,
+                    "after execute ex"
+                );
+            }
+        }
     }
 }
 
@@ -305,11 +312,7 @@ fn infer_request_id(execute_data: &mut ExecuteData) -> Option<i64> {
 
     let mut prev_execute_data_ptr = execute_data.as_mut_ptr();
     loop {
-        let Some(prev_execute_data) =
-            (unsafe { ExecuteData::try_from_mut_ptr(prev_execute_data_ptr) })
-        else {
-            return None;
-        };
+        let prev_execute_data = (unsafe { ExecuteData::try_from_mut_ptr(prev_execute_data_ptr) })?;
         let func_name = prev_execute_data.func().get_function_name();
         if !func_name
             .map(|s| s == &HACK_SWOOLE_ON_REQUEST_FUNCTION_NAME.as_bytes())
@@ -318,9 +321,7 @@ fn infer_request_id(execute_data: &mut ExecuteData) -> Option<i64> {
             prev_execute_data_ptr = unsafe { (*prev_execute_data_ptr).prev_execute_data };
             continue;
         }
-        let Some(request) = prev_execute_data.get_mut_parameter(0).as_mut_z_obj() else {
-            return None;
-        };
+        let request = prev_execute_data.get_mut_parameter(0).as_mut_z_obj()?;
         match request.get_mut_property("fd").as_long() {
             Some(fd) => return Some(fd),
             None => {
@@ -356,146 +357,155 @@ pub mod observer {
     pub unsafe extern "C" fn observer_handler(
         execute_data: *mut sys::zend_execute_data,
     ) -> sys::zend_observer_fcall_handlers {
-        let Some(execute_data) = ExecuteData::try_from_mut_ptr(execute_data) else {
-            return Default::default();
-        };
-
-        let (function_name, class_name) = match get_function_and_class_name(execute_data) {
-            Ok(x) => x,
-            Err(err) => {
-                error!(?err, "get function and class name failed");
+        unsafe {
+            let Some(execute_data) = ExecuteData::try_from_mut_ptr(execute_data) else {
                 return Default::default();
-            }
-        };
+            };
 
-        trace!(
-            ?function_name,
-            ?class_name,
-            "observer_handler function and class name"
-        );
-
-        let Some(function_name) = function_name else {
-            return Default::default();
-        };
-
-        if function_name == HACK_SWOOLE_ON_REQUEST_FUNCTION_NAME {
-            return Default::default();
-        }
-
-        if select_plugin_hook(class_name.as_deref(), &function_name).is_none() {
-            return Default::default();
-        }
-
-        sys::zend_observer_fcall_handlers {
-            begin: Some(observer_begin),
-            end: Some(observer_end),
-        }
-    }
-
-    unsafe extern "C" fn observer_begin(execute_data: *mut sys::zend_execute_data) {
-        let Some(execute_data) = ExecuteData::try_from_mut_ptr(execute_data) else {
-            return;
-        };
-        trace!(execute_data_ptr=?execute_data.as_ptr(), "start observer_begin");
-
-        let Ok((function_name, class_name)) = get_function_and_class_name(execute_data) else {
-            return;
-        };
-
-        trace!(
-            ?function_name,
-            ?class_name,
-            "observer_begin function and class name"
-        );
-
-        let Some(function_name) = function_name else {
-            return;
-        };
-
-        let Some((before, _)) = select_plugin_hook(class_name.as_deref(), &function_name) else {
-            return;
-        };
-
-        let request_id = infer_request_id(execute_data);
-        trace!(
-            ?request_id,
-            ?function_name,
-            ?class_name,
-            "observer_begin infer request id"
-        );
-
-        let result =
-            match catch_unwind_result(AssertUnwindSafe(|| before(request_id, execute_data))) {
-                Ok(result) => result,
+            let (function_name, class_name) = match get_function_and_class_name(execute_data) {
+                Ok(x) => x,
                 Err(err) => {
-                    error!(
-                        ?request_id,
-                        ?function_name,
-                        ?class_name,
-                        ?err,
-                        "run observer_begin hook failed"
-                    );
-                    return;
+                    error!(?err, "get function and class name failed");
+                    return Default::default();
                 }
             };
 
-        RESULT_MAP.insert(execute_data.as_ptr(), result);
+            trace!(
+                ?function_name,
+                ?class_name,
+                "observer_handler function and class name"
+            );
+
+            let Some(function_name) = function_name else {
+                return Default::default();
+            };
+
+            if function_name == HACK_SWOOLE_ON_REQUEST_FUNCTION_NAME {
+                return Default::default();
+            }
+
+            if select_plugin_hook(class_name.as_deref(), &function_name).is_none() {
+                return Default::default();
+            }
+
+            sys::zend_observer_fcall_handlers {
+                begin: Some(observer_begin),
+                end: Some(observer_end),
+            }
+        }
     }
 
-    unsafe extern "C" fn observer_end(
-        execute_data: *mut sys::zend_execute_data, retval: *mut sys::zval,
-    ) {
-        let Some(execute_data) = ExecuteData::try_from_mut_ptr(execute_data) else {
-            return;
-        };
-        trace!(execute_data_ptr=?execute_data.as_ptr(), "start observer_end");
+    #[allow(static_mut_refs)]
+    unsafe extern "C" fn observer_begin(execute_data: *mut sys::zend_execute_data) {
+        unsafe {
+            let Some(execute_data) = ExecuteData::try_from_mut_ptr(execute_data) else {
+                return;
+            };
+            trace!(execute_data_ptr=?execute_data.as_ptr(), "start observer_begin");
 
-        let Some((_, result)) = RESULT_MAP.remove(&execute_data.as_ptr()) else {
-            return;
-        };
+            let Ok((function_name, class_name)) = get_function_and_class_name(execute_data) else {
+                return;
+            };
 
-        let mut null = ZVal::from(());
-        let ret = match ZVal::try_from_mut_ptr(retval) {
-            Some(ret) => ret,
-            None => &mut null,
-        };
+            trace!(
+                ?function_name,
+                ?class_name,
+                "observer_begin function and class name"
+            );
 
-        let Ok((function_name, class_name)) = get_function_and_class_name(execute_data) else {
-            return;
-        };
+            let Some(function_name) = function_name else {
+                return;
+            };
 
-        trace!(
-            ?function_name,
-            ?class_name,
-            "observer_end function and class name"
-        );
+            let Some((before, _)) = select_plugin_hook(class_name.as_deref(), &function_name)
+            else {
+                return;
+            };
 
-        let Some(function_name) = function_name else {
-            return;
-        };
-
-        let Some((_, after)) = select_plugin_hook(class_name.as_deref(), &function_name) else {
-            return;
-        };
-
-        let request_id = infer_request_id(execute_data);
-        trace!(
-            ?request_id,
-            ?function_name,
-            ?class_name,
-            "observer_end infer request id"
-        );
-
-        if let Err(err) = catch_unwind_result(AssertUnwindSafe(|| {
-            after(request_id, result, execute_data, ret)
-        })) {
-            error!(
+            let request_id = infer_request_id(execute_data);
+            trace!(
                 ?request_id,
                 ?function_name,
                 ?class_name,
-                ?err,
-                "run observer_end hook failed"
+                "observer_begin infer request id"
             );
-        };
+
+            let result =
+                match catch_unwind_result(AssertUnwindSafe(|| before(request_id, execute_data))) {
+                    Ok(result) => result,
+                    Err(err) => {
+                        error!(
+                            ?request_id,
+                            ?function_name,
+                            ?class_name,
+                            ?err,
+                            "run observer_begin hook failed"
+                        );
+                        return;
+                    }
+                };
+
+            RESULT_MAP.insert(execute_data.as_ptr(), result);
+        }
+    }
+
+    #[allow(static_mut_refs)]
+    unsafe extern "C" fn observer_end(
+        execute_data: *mut sys::zend_execute_data, retval: *mut sys::zval,
+    ) {
+        unsafe {
+            let Some(execute_data) = ExecuteData::try_from_mut_ptr(execute_data) else {
+                return;
+            };
+            trace!(execute_data_ptr=?execute_data.as_ptr(), "start observer_end");
+
+            let Some((_, result)) = RESULT_MAP.remove(&execute_data.as_ptr()) else {
+                return;
+            };
+
+            let mut null = ZVal::from(());
+            let ret = match ZVal::try_from_mut_ptr(retval) {
+                Some(ret) => ret,
+                None => &mut null,
+            };
+
+            let Ok((function_name, class_name)) = get_function_and_class_name(execute_data) else {
+                return;
+            };
+
+            trace!(
+                ?function_name,
+                ?class_name,
+                "observer_end function and class name"
+            );
+
+            let Some(function_name) = function_name else {
+                return;
+            };
+
+            let Some((_, after)) = select_plugin_hook(class_name.as_deref(), &function_name) else {
+                return;
+            };
+
+            let request_id = infer_request_id(execute_data);
+            trace!(
+                ?request_id,
+                ?function_name,
+                ?class_name,
+                "observer_end infer request id"
+            );
+
+            if let Err(err) = catch_unwind_result(AssertUnwindSafe(|| {
+                after(request_id, result, execute_data, ret)
+            })) {
+                error!(
+                    ?request_id,
+                    ?function_name,
+                    ?class_name,
+                    ?err,
+                    "run observer_end hook failed"
+                );
+            };
+        }
     }
 }
