@@ -16,7 +16,8 @@
 use crate::{
     channel::Reporter,
     execute::{register_execute_functions, register_observer_handlers},
-    util::{get_sapi_module_name, get_str_ini_with_default, IPS},
+    log::PsrLogLevel,
+    util::{IPS, get_sapi_module_name, get_str_ini_with_default},
     worker::init_worker,
     *,
 };
@@ -25,6 +26,7 @@ use once_cell::sync::Lazy;
 use phper::{arrays::ZArr, ini::ini_get, sys};
 use skywalking::{
     common::random_generator::RandomGenerator,
+    logging::logger::{self, Logger},
     trace::tracer::{self, Tracer},
 };
 use std::{
@@ -33,10 +35,12 @@ use std::{
     os::unix::prelude::OsStrExt,
     path::{Path, PathBuf},
     str::FromStr,
+    sync::Arc,
     time::SystemTime,
 };
+use time::format_description::well_known::Rfc3339;
 use tracing::{debug, error, info, metadata::LevelFilter};
-use tracing_subscriber::{EnvFilter, FmtSubscriber};
+use tracing_subscriber::{EnvFilter, FmtSubscriber, fmt::time::OffsetTime};
 
 static IS_ENABLE: Lazy<bool> = Lazy::new(|| {
     if !ini_get::<bool>(SKYWALKING_AGENT_ENABLE) {
@@ -157,6 +161,12 @@ pub static INJECT_CONTEXT: Lazy<bool> =
 pub const IS_ZEND_OBSERVER_CALLED_FOR_INTERNAL: bool =
     sys::PHP_MAJOR_VERSION > 8 || (sys::PHP_MAJOR_VERSION == 8 && sys::PHP_MINOR_VERSION >= 2);
 
+pub static PSR_LOGGING_LEVEL: Lazy<PsrLogLevel> = Lazy::new(|| {
+    get_str_ini_with_default(SKYWALKING_AGENT_PSR_LOGGING_LEVEL)
+        .as_str()
+        .into()
+});
+
 pub fn init() {
     if !is_enable() {
         return;
@@ -182,6 +192,7 @@ pub fn init() {
     Lazy::force(&KAFKA_BOOTSTRAP_SERVERS);
     Lazy::force(&KAFKA_PRODUCER_CONFIG);
     Lazy::force(&INJECT_CONTEXT);
+    Lazy::force(&PSR_LOGGING_LEVEL);
 
     if let Err(err) = try_init_logger() {
         eprintln!("skywalking_agent: initialize logger failed: {}", err);
@@ -220,12 +231,16 @@ pub fn init() {
     // Initialize Agent worker.
     init_worker();
 
+    let reporter = Arc::new(Reporter::new(&*SOCKET_FILE_PATH));
+
     tracer::set_global_tracer(Tracer::new(
         &*SERVICE_NAME,
         &*SERVICE_INSTANCE,
-        Reporter::new(&*SOCKET_FILE_PATH),
+        reporter.clone(),
     ));
 
+    logger::set_global_logger(Logger::new(&*SERVICE_NAME, &*SERVICE_INSTANCE, reporter));
+
     // Hook functions.
     register_execute_functions();
     register_observer_handlers();
@@ -255,7 +270,7 @@ fn try_init_logger() -> anyhow::Result<()> {
         .unwrap_or_default();
     let log_file = log_file.trim();
     if log_file.is_empty() {
-        bail!("log file cant't be empty when log enabled");
+        bail!("log file can't be empty when log enabled");
     }
 
     let path = Path::new(log_file);
@@ -277,6 +292,10 @@ fn try_init_logger() -> anyhow::Result<()> {
         .with_env_filter(filter)
         .with_ansi(false)
         .with_writer(file)
+        .with_timer(
+            OffsetTime::local_rfc_3339()
+                .unwrap_or_else(|_| OffsetTime::new(time::UtcOffset::UTC, Rfc3339)),
+        )
         .finish();
 
     tracing::subscriber::set_global_default(subscriber)?;
@@ -286,7 +305,7 @@ fn try_init_logger() -> anyhow::Result<()> {
 
 #[inline]
 fn get_module_registry() -> &'static ZArr {
-    unsafe { ZArr::from_ptr(&sys::module_registry) }
+    unsafe { ZArr::from_ptr(&raw const sys::module_registry) }
 }
 
 #[inline]
