@@ -14,18 +14,18 @@
 // limitations under the License.
 
 use crate::module::{
-    is_standalone_reporter_type, AUTHENTICATION, ENABLE_TLS, HEARTBEAT_PERIOD,
-    PROPERTIES_REPORT_PERIOD_FACTOR, REPORTER_TYPE, SERVER_ADDR, SERVICE_INSTANCE, SERVICE_NAME,
-    SOCKET_FILE_PATH, SSL_CERT_CHAIN_PATH, SSL_KEY_PATH, SSL_TRUSTED_CA_PATH, WORKER_THREADS,
+    AUTHENTICATION, ENABLE_TLS, HEARTBEAT_PERIOD, PROPERTIES_REPORT_PERIOD_FACTOR, REPORTER_TYPE,
+    SERVER_ADDR, SERVICE_INSTANCE, SERVICE_NAME, SOCKET_FILE_PATH, SSL_CERT_CHAIN_PATH,
+    SSL_KEY_PATH, SSL_TRUSTED_CA_PATH, WORKER_THREADS, is_standalone_reporter_type,
 };
 #[cfg(feature = "kafka-reporter")]
 use crate::module::{KAFKA_BOOTSTRAP_SERVERS, KAFKA_PRODUCER_CONFIG};
 #[cfg(feature = "kafka-reporter")]
 use skywalking_php_worker::reporter::KafkaReporterConfiguration;
 use skywalking_php_worker::{
-    new_tokio_runtime,
+    HeartBeatConfiguration, WorkerConfiguration, new_tokio_runtime,
     reporter::{GrpcReporterConfiguration, ReporterConfiguration},
-    start_worker, HeartBeatConfiguration, WorkerConfiguration,
+    start_worker,
 };
 use std::{cmp::Ordering, num::NonZeroUsize, process::exit, thread::available_parallelism};
 use tracing::error;
